function F=calcrelflux(section,geometry,reflevel,rv,stnpairs);

% function F=calcrelflux(section,geometry,reflevel,rv,stnpairs);
%
% calculate the relative flux of section "section"
% relative to reference level number reflevel.
% reflevel=-1 for bottom-referenced transport.

% include the following line to calculate the
% flux through particular station pair indices

if ~exist('rv') rv=0; end;
if (rv~=0)
    disp('code modified so that rv=0.')
    rv=0;
end;

sectdir='/phod007/lumpkin/dobox/sections';

clf;

if (~strcmp(section(length(section)-2: ...
	length(section)),'mat'))
  section=[section,'.mat'];
end;

directory='/phod007/lumpkin/dobox/sections/';
properties=['mass '; 'salam';'potmp'];
sectfiles=[directory,section];

save geo directory geometry properties sectfiles reflevel rv;
checkgeo;pause(.5);

%%%% DOBOX code here, to calculate relative fluxes %%%%
vmag=.1;
[Abase, nlayers, nsectpairs] = build_a(geometry, sectfiles, properties);
[mAbase,nAbase]     = size(Abase);
[nproperties,m]     = size(properties);
[nboxes,nsections]  = size(geometry);
nboxeqns            = (nlayers+1)*nproperties;
nsurfs              = nlayers + 1;
clear m
[row_beg, row_end, col_beg, col_end, eqn_beg, eqn_end] = ...
      set_index(nboxes,nsections,nproperties,nsectpairs,nlayers,nboxeqns);
refvels_nounique;    % create refvel_*.mat files

%%%%% code here for unique reference level values %%%%%%%%
glev;
if strcmp(sectname,'denstrait')
  q=find(glevels>=27.879); reflevel=q(1);
  RV(8)=.3; RV(9)=.06;
  RV(21)=.8;RV(20)=.4;RV(19)=.1;
  RV(1:7)=-.235;

elseif strcmp(sectname,'ar18e1');
  reflevel=length(glevels);
  RV(1:5)=-.144;	% .9 Sv N Irminger Current (layers 1-15)
  % DSOW: 2Sv in layers 38-45, .9Sv in layers 27-37
  RV(10)=.22;RV(9)=.21; RV(8)=.04;
  RV(19:21)=-.004; 	% 1.6 Sv EGC layers 1-15 pairs 7-21

elseif strcmp(sectname,'fbc')
  q=find(glevels>=27.879); reflevel=q(1);
  RV(3)=.7;

elseif strcmp(sectname,'ice2scot')
  q=find(glevels>=27.879); reflevel=q(1);
  RV(15)=.47;		% FBC: 1.4 Sv at sig_thet>27.975
  RV(19:29)=-.045;	% -4 Sv SPMW across Ice-Far Rise
  RV(31:32)=.09;		%   and (at same time) .7--1 Sv denser
  RV(1:3)=-.035;		% -3 Sv SPMW over WTR

elseif strcmp(sectname,'ar07w_a')
  q=find(glevels>=27.949); reflevel=q(1);
  RV(16:17)=.14;  % 11.0 Sv for pairs 16-23
  RV(15)=.1; RV(14)=.05; RV(13)=.01; RV(4:6)=-.026; RV(3)=-.229;

elseif strcmp(sectname,'ar07ed_ebc'); % Ekman: 1.16Sv S-ward
  q=find(glevels>=27.879); reflevel=q(1);
  % EGC: 15 Sv S, pairs 1:5 [Bacon 97]
  RV(1)=-.1;RV(2)=-.2;RV(3)=-.3; RV(4)=-.04;RV(5)=-.03;
  % EGC: 32.2 Sv S, pairs 1:12 [Bersh 95]
  RV(6:8)=-.035;
  % Porcupine Bank (-15.7<lon<-15.3): 30cm/s sfc currents
  RV(50)=.18;RV(51)=.08;
  RV=RV+1.5e-3; % balance Ekman 

elseif strcmp(sectname,'a01e'); % Ekman: 1.16Sv S-ward
  q=find(glevels>=27.879); reflevel=q(1);
  % EGC: 15 Sv S, lon2<-41.15 (pairs 1:5) [Bacon 97]
  RV(1)=-.1;RV(2)=-.2;RV(3)=-.3; RV(4)=-.05;RV(5)=-.03;
  % EGC: 32.2 Sv S, lon2<-35.8 (pairs 1:12) [Bersh 95]
  RV(6:8)=-.035;RV(9)=-.028;
  % Porcupine Bank (-15.7<lon<-15.3): 30cm/s sfc currents
  RV(50)=.1;
  RV=RV+2.33e-3; % balance Ekman

elseif strcmp(sectname,'ar07e_g'); % Ekman: 1.16Sv S-ward
  q=find(glevels>=27.879); reflevel=q(1);
  % EGC: 15 Sv S, lon2<-41.15 (pairs 1:5) [Bacon 97]
  RV(1)=-.1;RV(2)=-.2;RV(3)=-.3; RV(4)=-.05;RV(5)=-.03;
  % EGC: 32.2 Sv S, lon2<-35.8 (pairs 1:12) [Bersh 95]
  RV(6:9)=-.035;  RV(10)=-.016;
  % Porcupine Bank (-15.7<lon<-15.3): 30cm/s sfc currents
  RV(50)=.28;RV(51)=.2;
  RV=RV-1.91e-3;  % balance Ekman

elseif strcmp(sectname,'ar07e_h'); % Ekman: 1.16Sv S-ward
  q=find(glevels>=27.879); reflevel=q(1);
  % EGC: 15 Sv S, lon2<-41.15 (pairs 1:5) [Bacon 97]
  RV(1)=-.1;RV(2)=-.2;RV(3)=-.29; RV(4)=-.04;RV(5)=-.03;
  % EGC: 32.2 Sv S, lon2<-35.8 (pairs 1:12) [Bersh 95]
  RV(6:8)=-.035;  RV(9)=-.03;
  % Porcupine Bank (-15.7<lon<-15.3): 30cm/s sfc currents
  RV(50)=.17;RV(51)=.27;
  RV=RV-8.2e-4;  % balance Ekman

elseif strcmp(sectname,'a01e'); % Ekman: 1.16Sv S-ward
  q=find(glevels>=27.879); reflevel=q(1);
  % EGC: 15 Sv S, pairs 1:5 [Bacon 97]
  RV(1)=-.1;RV(2)=-.2;RV(3)=-.3; RV(4)=-.04;RV(5)=-.03;
  % EGC: 32.2 Sv S, pairs 1:12 [Bersh 95]
  RV(6:8)=-.035;
  RV(50:51)=.15;
  RV=RV+1.5e-3; % balance Ekman

elseif strcmp(sectname,'bering');
  reflevel=glevels(length(glevels));
  RV=RV+.22; % gives .8 Sv, 28.84 Gg/s salt.

elseif strcmp(sectname,'arch');
  reflevel=glevels(length(glevels));
  RV=RV-.04;  % gives .82 Sv, 28.13 Gg/s salt.

elseif strcmp(sectname,'a05fs');
  reflevel=length(glevels);
  RV=RV+.285;

elseif strcmp(sectname,'ar01afs');
  reflevel=length(glevels);
  RV=RV+.163;
  
elseif strcmp(sectname,'fs_south');
  reflevel=length(glevels);
  RV=RV-.1917;   % 31 Sv north
  
elseif strcmp(sectname,'fs_north');
  reflevel=length(glevels);
  RV=RV+.173;   % 31 Sv north
  
elseif strcmp(sectname,'providence');
    reflevel=length(glevels);
    RV=RV+.103; % 0 Sv

elseif strcmp(sectname,'a05int'); % Ekman: +4.30Sv N

  reflevel=length(glevels);
  eval(['load ',sectdir,'/a05int_raw' ...
         ' binPair_vel lon bin_press bottom'])
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  bottom=[bottom(1:length(bottom)-1),bottom(2:length(bottom))];
  bottom=nanmin(bottom')';
  for j=1:length(lon);
    q=find(isfinite(binPair_vel(:,j)));
    binPair_vel(:,j)=binPair_vel(:,j)- ...
        binPair_vel(last(q),j);
  end;
  % shift ref level to 3000dbar (Rintoul and Wunsch 1991)
  refp=3000;
  q=min(find(bin_press>=refp));
  q2=find(bottom>=refp);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));
  RV(q2(q))=0;
 
  % balance Ekman and FS flow: want 35.3 Sv south:
  %     4.3Sv N Ekman + 31.0 Sv N in Florida Strait
  RV=RV-8.7e-4;

elseif strcmp(sectname,'ar01aint'); % Ekman: +4.3Sv N
  % want -35.3 Sv: Ekman + florida strait
  reflevel=length(glevels);
  eval(['load ',sectdir,'/a05int_raw' ...
         ' binPair_vel lon bin_press bottom'])
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  for j=1:length(lon);
    q=find(isfinite(binPair_vel(:,j)));
    binPair_vel(:,j)=binPair_vel(:,j)- ...
        binPair_vel(last(q),j);
  end;
  % shift ref level to 3000m (Rintoul and Wunsch 1991)
  q=find(bin_press==3000);
  q2=find(bottom>3000);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));RV(q2(q))=0;
  % balance Ekman and FS flow (want -35.3 Sv)
  RV=RV-4e-4;

elseif strcmp(sectname,'a06'); % Ekman: +8.42Sv N
  q=find(glevels>=28.05); reflevel=q(1);
  RV=RV+0;
  
elseif strcmp(sectname,'ar19a'); % Ekman: 2.46Sv S
    
  load ../sections/ar19a lon bin_press bin_temp lon lat bottom;
  q=find(glevels>=27.879); reflevel=q(1);
  
  if (0)    % no WBC modification
      % adjust to get +2.46 Sv (-1*Ekman transport)
      RV=RV-0.52e-3;
  else  % adjustments to reference velocities from
  % Meinen, 2001: DSR I 48, 1553-1580.
  
  mann=-43.85;  % longitude of Mann Eddy center
  bottom=bottom(1:length(lon)-1)+diff(bottom)/2;
  
  % Identify the core of the NAC (where the 10dgC
  % isotherm crosses 450dbar)
  temp=bin_temp(find(bin_press==450),:);
  lonhr=min(lon):.01:max(lon);
  lathr=interp1(lon,lat,lonhr,'linear');
  temp=interp1(lon,temp,lonhr,'linear');
  lon_0=lonhr(min(find(temp>10)));
  lat_0=lathr(min(find(temp>10)));
  % convert lon, lat to pair coordinates
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  lat=lat(1:length(lat)-1)+diff(lat)/2;
  
  % calculate distance (negative=west)
  % between station pairs and NAC core.
  dist=NaN*ones(size(lon));
  for jj=1:length(dist);
    dist(jj)=sw_dist([lat(jj) lat_0], ...
        [lon(jj) lon_0],'km');
    if (lon(jj)<lon_0) dist(jj)=-dist(jj); end;
  end;
  
  % load mean reference velocity on 27.879 surface
  %  (calculated by "calcstreammean.m" in NACpies directory)
  load /phod007/lumpkin/NACpies/48n_refvel d_s v27879
  % rescale so that max(d_s) is at mann eddy center 
  % for this repeat (instead of +200km)
  q=find(d_s>0);
  d_s(q)=d_s(q)/200*interp1(lon,dist,mann);
  % interpolate to dist for this repeat
  v2=interp1(d_s,v27879,dist,'linear');
  % extrapolate westward to shelf break (bottom==500)
  q=find(dist<0 & bottom'>500 & isnan(v2));
  v2(q)=v27879(1);
  % zero bottom ref level inshore of this
  q=find(dist<0 & isnan(v2)); v2(q)=0;
  % zero ref level east of mann eddy center
  v2(find(dist>interp1(lon,dist,mann)))=0;
  
  % match the time-mean net transport from -200km to Mann 
  % center (pairs 4:14):
  %   145 Sv northward - 30 Sv southward = 115 Sv
  %q=find(dist>-200 & lon<mann);
  v2=0.802*v2;
  RV=RV+v2;
  
  % East half of Mann eddy:  55Sv south.
  q=find(lon>=-43.85 & lon<=-41);  % pairs 15:18
  RV(q)=RV(q)-4.21e-2;
  
  % these adjustments give a net transport of 64 Sv north.
  % adjust in interior (west of eastern edge Mann eddy)
  % to get +2.46 Sv (-1*Ekman transport)
  q=19:length(lon); 
  RV(q)=RV(q)-6.59e-3;
  
  end;  % if adding WBC
  
elseif strcmp(sectname,'ar19c'); % Ekman: 2.46Sv S
  load ../sections/ar19c lon bin_press bin_temp lon lat bottom;
  q=find(glevels>=27.879); reflevel=q(1);  
  
  if (0)    % no WBC modification
      % adjust to get +2.46 Sv (-1*Ekman transport)
      RV=RV-0.43e-3;
  else  % adjustments to reference velocities from
  % Meinen, 2001: DSR I 48, 1553-1580.
  
  mann=-44.37;  % longitude of Mann Eddy center
  bottom=bottom(1:length(lon)-1)+diff(bottom)/2;
  
  % Identify the core of the NAC (where the 10dgC
  % isotherm crosses 450dbar)
  temp=bin_temp(find(bin_press==450),:);
  lonhr=min(lon):.01:max(lon);
  lathr=interp1(lon,lat,lonhr,'linear');
  temp=interp1(lon,temp,lonhr,'linear');
  lon_0=lonhr(min(find(temp>10)));
  lat_0=lathr(min(find(temp>10)));
  % convert lon, lat to pair coordinates
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  lat=lat(1:length(lat)-1)+diff(lat)/2;
  
  % calculate distance (negative=west)
  % between station pairs and NAC core.
  dist=NaN*ones(size(lon));
  for jj=1:length(dist);
    dist(jj)=sw_dist([lat(jj) lat_0], ...
        [lon(jj) lon_0],'km');
    if (lon(jj)<lon_0) dist(jj)=-dist(jj); end;
  end;
  
  % load mean reference velocity on 27.879 surface
  %  (calculated by "calcstreammean.m" in NACpies directory)
  load /phod007/lumpkin/NACpies/48n_refvel d_s v27879
  % rescale so that max(d_s) is at mann eddy center 
  % for this repeat (instead of +200km)
  q=find(d_s>0);
  d_s(q)=d_s(q)/200*interp1(lon,dist,mann);
  % interpolate to dist for this repeat
  v2=interp1(d_s,v27879,dist,'linear');
  % extrapolate westward to shelf break (bottom==500)
  q=find(dist<0 & bottom'>500 & isnan(v2));
  v2(q)=v27879(1);
  % zero bottom ref level inshore of this
  q=find(dist<0 & isnan(v2)); v2(q)=0;
  % zero ref level east of mann eddy center
  v2(find(dist>interp1(lon,dist,mann)))=0;
  
  % match the time-mean net transport from -200km to Mann core:
  %   145 Sv northward - 30 Sv southward = 115 Sv
  %q=find(dist>=-200 & lon<mann);    % pairs 6:15
  v2=1.103*v2;
  RV=RV+v2;
  
  % East half of Mann eddy:  55Sv south.
  q=find(lon>=-44.37 & lon<=-42.82);  % pairs 16:17
  RV(q)=RV(q)-6.29e-2;
  
  % these adjustments give a net transport of 67 Sv north.
  % adjust in interior (west of eastern edge Mann eddy)
  % to get +2.46 Sv (-1*Ekman transport)
  q=find(lon>-42.82);
  RV(q)=RV(q)-6.28e-3;
   
  end;    % if adding wbc
  
elseif strcmp(sectname,'ar19d'); % Ekman: 2.46Sv S
  load ../sections/ar19d lon bin_press bin_temp lon lat bottom;
  q=find(glevels>=27.879); reflevel=q(1);
  
  if (0)    % no WBC modification
      % adjust to get +2.46 Sv (-1*Ekman transport)
      RV=RV-0.10e-3;
  else  % adjustments to reference velocities from
  % Meinen, 2001: DSR I 48, 1553-1580.
  
  mann=-43.65;
  bottom=bottom(1:length(lon)-1)+diff(bottom)/2;
  
  % Identify the core of the NAC (where the 10dgC
  % isotherm crosses 450dbar)
  temp=bin_temp(find(bin_press==450),:);
  lonhr=min(lon):.01:max(lon);
  lathr=interp1(lon,lat,lonhr,'linear');
  temp=interp1(lon,temp,lonhr,'linear');
  lon_0=lonhr(min(find(temp>10)));
  lat_0=lathr(min(find(temp>10)));
  % convert lon, lat to pair coordinates
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  lat=lat(1:length(lat)-1)+diff(lat)/2;
  
  % calculate distance (negative=west)
  % between station pairs and NAC core.
  dist=NaN*ones(size(lon));
  for jj=1:length(dist);
    dist(jj)=sw_dist([lat(jj) lat_0], ...
        [lon(jj) lon_0],'km');
    if (lon(jj)<lon_0) dist(jj)=-dist(jj); end;
  end;
  
  % load mean reference velocity on 27.879 surface
  %  (calculated by "calcstreammean.m" in NACpies directory)
  load /phod007/lumpkin/NACpies/48n_refvel d_s v27879
  % rescale so that max(d_s) is at mann eddy center 
  % for this repeat (instead of +200km)
  q=find(d_s>0);
  d_s(q)=d_s(q)/200*interp1(lon,dist,mann);
  % interpolate to dist for this repeat
  v2=interp1(d_s,v27879,dist,'linear');
  % extrapolate westward to shelf break (bottom==500)
  q=find(dist<0 & bottom'>500 & isnan(v2));
  v2(q)=v27879(1);
  % zero bottom ref level inshore of this
  q=find(dist<0 & isnan(v2)); v2(q)=0;
  % zero ref level east of mann eddy center
  v2(find(dist>interp1(lon,dist,mann)))=0;
  
  % match the time-mean net transport from -200km to Mann 
  % center (pairs 7:17):
  %   145 Sv northward - 30 Sv southward = 115 Sv
  q=find(dist>-200 & lon<mann);
  v2=0.478*v2;
  RV=RV+v2;
  
  % East half of Mann eddy:  55Sv south.
  q=find(lon>=-43.65 & lon<=-40.95);  % pairs 18:21
  RV(q)=RV(q)-2.80e-2;
  
  % these adjustments give a net transport of 19 Sv north.
  % adjust in interior (west of eastern edge Mann eddy)
  % to get +2.46 Sv (-1*Ekman transport)
  q=find(lon>-40.95);
  RV(q)=RV(q)-1.76e-3;
  
  end;    % if adding WBC
  
elseif strcmp(sectname,'ar19f'); % Ekman: 2.46Sv S
  load ../sections/ar19f lon bin_press bin_temp lon lat bottom;
  q=find(glevels>=27.879); reflevel=q(1);
  
  if (0)    % no WBC modification
      % adjust to get +2.46 Sv (-1*Ekman transport)
      RV=RV-1.02e-3;
  else  % adjustments to reference velocities from
  % Meinen, 2001: DSR I 48, 1553-1580.
  
  mann=[-45.4 -43];  % longitude of Mann Eddy center, east edge
  bottom=bottom(1:length(lon)-1)+diff(bottom)/2;
  
  % Identify the core of the NAC (where the 10dgC
  % isotherm crosses 450dbar)
  temp=bin_temp(find(bin_press==450),:);
  lonhr=min(lon):.01:max(lon);
  lathr=interp1(lon,lat,lonhr,'linear');
  temp=interp1(lon,temp,lonhr,'linear');
  lon_0=lonhr(min(find(temp>10)));
  lat_0=lathr(min(find(temp>10)));
  % convert lon, lat to pair coordinates
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  lat=lat(1:length(lat)-1)+diff(lat)/2;
  
  % calculate distance (negative=west)
  % between station pairs and NAC core.
  dist=NaN*ones(size(lon));
  for jj=1:length(dist);
    dist(jj)=sw_dist([lat(jj) lat_0], ...
        [lon(jj) lon_0],'km');
    if (lon(jj)<lon_0) dist(jj)=-dist(jj); end;
  end;
  
  % load mean reference velocity on 27.879 surface
  %  (calculated by "calcstreammean.m" in NACpies directory)
  load /phod007/lumpkin/NACpies/48n_refvel d_s v27879
  % rescale so that max(d_s) is at mann eddy center 
  % for this repeat (instead of +200km)
  q=find(d_s>0);
  d_s(q)=d_s(q)/200*interp1(lon,dist,mann(1));
  % interpolate to dist for this repeat
  v2=interp1(d_s,v27879,dist,'linear');
  % extrapolate westward to shelf break (bottom==500)
  q=find(dist<0 & bottom'>500 & isnan(v2));
  v2(q)=v27879(1);
  % zero bottom ref level inshore of this
  q=find(dist<0 & isnan(v2)); v2(q)=0;
  % zero ref level east of mann eddy center
  v2(find(dist>interp1(lon,dist,mann(1))))=0;
  
  if (1)    % treat ar19f like the others
  % match the time-mean net transport from -200km to Mann 
  % center (pairs 6:11):
  %   145 Sv northward - 30 Sv southward = 115 Sv
  %q=find(dist>-200 & lon<mann(1));
    v2=2.737*v2;
    RV=RV+v2;
  
  % East half of Mann eddy:  55Sv south.
    q=find(lon>=mann(1) & lon<=mann(2));  % pair 12
    RV(q)=RV(q)-6.17e-2;
  
  % these adjustments give a net transport of 63 Sv north.
  % adjust in interior (west of eastern edge Mann eddy)
  % to get +2.46 Sv (-1*Ekman transport)
    q=find(lon>mann(2));
    RV(q)=RV(q)-5.92e-3;
    
    else
  % no mann eddy here: impose 115-55=60Sv north in NAC
  q=find(dist>-200 & lon<mann(1));
  v2=1.413*v2;
  RV=RV+v2;
  
  % net transport 67.5 east of NAC.
  % adjust in interior to get +2.46 Sv (-1*Ekman transport)
  q=find(lon>mann(1));
  RV(q)=RV(q)-5.84e-3;
    end; % with/ without Mann code
  
  end;    % if adding WBC
  
elseif strcmp(sectname,'a02_97'); % Ekman: 2.46Sv S
      
  load ../sections/a02_97 lon bin_press bin_temp lon lat bottom;
  q=find(glevels>=27.879); reflevel=q(1);
  
  if (0)    % no WBC modification
      % adjust to get +2.46 Sv (-1*Ekman transport)
      RV=RV-0.45e-3;
  else  % adjustments to reference velocities from
  % Meinen, 2001: DSR I 48, 1553-1580.
  
  mann=-43.54;
  bottom=bottom(1:length(lon)-1)+diff(bottom)/2;
  
  % Identify the core of the NAC (where the 10dgC
  % isotherm crosses 450dbar)
  temp=bin_temp(find(bin_press==450),:);
  lonhr=min(lon):.01:max(lon);
  lathr=interp1(lon,lat,lonhr,'linear');
  temp=interp1(lon,temp,lonhr,'linear');
  lon_0=lonhr(min(find(temp>10)));
  lat_0=lathr(min(find(temp>10)));
  % convert lon, lat to pair coordinates
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  lat=lat(1:length(lat)-1)+diff(lat)/2;
  
  % calculate distance (negative=west)
  % between station pairs and NAC core.
  dist=NaN*ones(size(lon));
  for jj=1:length(dist);
    dist(jj)=sw_dist([lat(jj) lat_0], ...
        [lon(jj) lon_0],'km');
    if (lon(jj)<lon_0) dist(jj)=-dist(jj); end;
  end;
  
  % load mean reference velocity on 27.879 surface
  %  (calculated by "calcstreammean.m" in NACpies directory)
  load /phod007/lumpkin/NACpies/48n_refvel d_s v27879
  % rescale so that max(d_s) is at mann eddy center 
  % for this repeat (instead of +200km)
  q=find(d_s>0);
  d_s(q)=d_s(q)/200*interp1(lon,dist,mann);
  % interpolate to dist for this repeat
  v2=interp1(d_s,v27879,dist,'linear');
  % extrapolate westward to shelf break (bottom==500)
  q=find(dist<0 & bottom'>500 & isnan(v2));
  v2(q)=v27879(1);
  % zero bottom ref level inshore of this
  q=find(dist<0 & isnan(v2)); v2(q)=0;
  % zero ref level east of mann eddy center
  v2(find(dist>interp1(lon,dist,mann)))=0;
  
  % problem with A02_97:  -200km (stream coords)
  % is in the center of an anomalous anticyclonic eddy.
  % For this section, include the eddy (starting at
  % cast 7) when matching the net mean transport
  % for -200km to Mann Eddy Center  (115 Sv)
  %q=find(dist>=-200 & lon<mann); % pairs 10:16
  v2=1.223*v2;  % adjusted for pairs 10:16
  RV=RV+v2;
  
  % East half of Mann eddy:  55Sv south.
  q=find(lon>=-43.54 & lon<=-40.74);  % pairs 17:19
  RV(q)=RV(q)-2.57e-2;
  
  % these adjustments give a net transport of 60 Sv north.
  % adjust in interior (west of eastern edge Mann eddy)
  % to get +2.46 Sv (-1*Ekman transport)
  q=find(lon>-40.74);
  RV(q)=RV(q)-3.46e-3;
 
  end;     % if adding WBC
  
elseif strcmp(sectname,'hycom_sect')
  q=find(glevels>=27.879);reflevel=q(1);
  
  % Balance Ekman (Ek=2.13 Sv south)
  RV=RV-0.96e-3;
  
elseif strcmp(sectname,'a08')	% Ekman: 9.71Sv S
  reflevel=length(glevels);

    eval(['load ',sectdir,'/a08_raw' ...
         ' binPair_vel lon bin_press'])
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  for j=1:length(lon);
    q=find(isfinite(binPair_vel(:,j)));
    binPair_vel(:,j)=binPair_vel(:,j)- ...
        binPair_vel(last(q),j);
  end;

  % shift ref level to 1100m west of 35.5W
  q=find(bin_press==1100);
  q2=find(lon<=-35.5);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));RV(q2(q))=0;

  % shift ref level to 3800m between 35.5W and 17.67W
  % (Brazil Basin)  (stations 4:6 stay bottom-referenced)
  q=find(bin_press==3800);
  q2=find(lon>=-35.5 & lon<=-17.67);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));RV(q2(q))=0;

  % shift ref level to 2400m between 17.67W and 10.17W (MAR)
  q=find(bin_press==2400);
  q2=find(lon>=-17.67 & lon<=-10.17);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));RV(q2(q))=0;

  % shift ref level to 4000m east of 10.17W (Angola Basin)
  q=find(bin_press==4000);
  q2=find(lon>=-10.17);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));RV(q2(q))=0;

  RV=RV-1.23e-4;

  RV=RV+.001;

elseif strcmp(sectname,'a10')
	% adjustments from McDonagh and King (03 JPO review)

  q=find(glevels>=28.175); reflevel=q(1);
  load /phod007/lumpkin/dobox/sections/a10_raw lon
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  % Brazil Current (inshore): 25 Sv south
  q=find(lon<-46.4); RV(q)=-.195;
  % Brazil Current recirc: 7.5 Sv north
  q=find(lon>-46.4 & lon<-44.8); RV(q)=.015;
  
  % Vema Channel AABW (gam>28.175): 2 Sv north
  %q=find(lon<-35.8); RV(q)=RV(q)+0;  % already satisfied
  % Brazil Basin AABW: 3 Sv north
  q=find(lon>-33 & lon<-17.8);RV(q)=RV(q)+.003;
  % Cape Basin AABW: 0 Sv (blocked by Walvis)
  %q=find(lon>-3); RV(q)=RV(q)+0;  % already satisfied
  % Also by McD&K: 0 Sv on eastern ends of A10,A11.
  
elseif strcmp(sectname,'a11')	% Saunders & King (1995)
				% Ekman: 4.35Sv N
  q=find(glevels>=28.175); reflevel=q(1);	% SK95
  load /phod007/lumpkin/dobox/sections/a11_raw lon
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  % 45 Sv WBC (Malvinas Current, pairs 1-5; SK95)
  %%%%q=find(lon<=-58.4);RV(q)=.15;
  q=find(lon>-59.25 & lon<-58.4);RV(q)=.27;
  % -5 Sv EBC (pairs 85-89; SK95)
  q=find(lon>=14.5); RV(q)=-.037;
  % 0 Sv bottom water (gam>28.175) into Cape Basin
  %  (pairs 60:81; blocked by Walvis Ridge) (SK95)
  q=find(lon>=-6 & lon<=12.1); RV(q)=-.0003;
  % 6 Sv bottom water (gam>28.175) into Argentine Basin
  %  (pairs 9-45)
  q=find(lon>=-57.3 & lon<=-21.1); RV(q)=.0013;
  % uniform s-ward flow across station pairs
  %   over MAR to get 0 net flow (-5.4 Sv to balance Ek)
  q=find(lon>=-15.7 & lon<=-12.5);
  retflow=-.022;RV(q)=retflow;

elseif strcmp(sectname,'ar16d')		
	% Ek: .13 Sv, 4.7e6 kg/s salt West

  reflevel=length(glevels);  % bottom
  eval(['load ',sectdir,'/ar16d_raw lat'])
  lat=lat(1:length(lat)-1)+diff(lat)/2;

  % shift to cancel net flow at sub-NACW densities
  % (<7 degC; gamma>=27.94)
  q=find(lat>33.85 & lat<36.2); RV(q)=RV(q)-5e-3;
  q=find(lat>34 & lat<34.5); RV(q)=5e-3;
  % 2 Sv outflow in layers 15-20, met by magnifying
  % westward flow against Spain
  q=find(lat>36.2 & lat<36.75); RV(q)=.02;
  % eastward flow of surface water against Africa
  % to balance net Ekman (0.15Sv west)
  q=find(lat<33.85); RV(q)=-1.6e-1;

elseif strcmp(sectname,'gibraltar')
  q=find(glevels>=27.4); reflevel=q(1);
  % .7 Sv Med water (S>36.4, layers 14-45) outflow
  RV(3:4)=-2e-1;
  % 0 Sv net exchange
  RV=RV+5e-2;

elseif strcmp(sectname,'p06')
    
    % interface between Wijffels et al. (2001)
    % deep and bottom water for ZVS
  q=find(glevels>=28.125); reflevel=q(1);
  eval(['load ',sectdir,'/p06_raw lon'])
  lon=lon(1:length(lon)-1)+diff(lon)/2;

  % S New Cal. Trough (162-168E): cul-de-sac for 
  % gamma>27.9 (lay22-45)
  q=find(lon>=162.5 & lon<=166.5); % pairs 28:34
  RV(q)=RV(q)-1.00e-3;
  
  % 14.8 Sv (layers 21-45) N against Kermadec Ridge
  %	as seen by PCM9 (179-169W; pairs 64:88)
  % in layers below 3250 m (layers 31:45)
  q=find(lon>=-179 & lon<=-169); 
  RV(q)=RV(q)+4.14e-3;
  % this gives:
  % 4.1 Sv S, layers 21:30 (should be 1 Sv N)
  % 7.5 Sv N, layers 31:40 (should be 8.8 Sv N)
  % 7.3 Sv N, layers 41:45 (should be 6.0 Sv N)
  
  % Constraints from Wijffels et al Table 3
  % West Tasman Sea: .5 Sv N, gamma>28.1 (layers 35:45)
  q=find(lon>=154 & lon<=160);  % pairs 7:22
  RV(q)=RV(q)+0.18e-3;
  % Central Tasman Sea: 0 Sv at gamma>27.95 (layers 23:45)
  q=find(lon>=160 & lon<173);   % pairs 23:48
  RV(q)=RV(q)+0.27e-3;
  % East Tasman Sea: 0 Sv at gamma>27.95 (layers 23:45)
  q=find( (lon>=173 & lon<=180) | (lon<-179));
    % pairs 49:63
  RV(q)=RV(q)-0.15e-3;
  
  % Adjustments so far yield net transport of 10.43 Sv N.
  % This is sufficiently close to PIT (12 Sv N)
  % minus Ekman (0.6 Sv N) = 11.4 Sv N.
  %     East Australia Current 
  %     q=find(lon>0 & lon<154);  % pairs 1-6
  % Prior overturning circulation is 21.2 Sv bottom/deep
  % water cell.  Wijffels et al: 16 Sv.
  
elseif strcmp(sectname,'p03')
  reflevel=length(glevels);
  eval(['load ',sectdir, ...
     '/p03_raw binPair_vel lon bin_press bottom']);
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  bottom=[bottom(1:length(bottom)-1),bottom(2:length(bottom))];
  bottom=nanmin(bottom')';
  for j=1:length(lon);
    q=find(isfinite(binPair_vel(:,j)));
    binPair_vel(:,j)=binPair_vel(:,j)- ...
        binPair_vel(last(q),j);
  end;
  % shift ref level to 2000dbar (Roemmich and McCallister 1989)
  refp=2000;
  q=min(find(bin_press>=refp));
  q2=find(bottom>=refp);
  RV(q2)=RV(q2)-binPair_vel(q,q2);
  q=find(isnan(RV(q2)));
  RV(q2(q))=0;

  % No transport at gamma>27.52 (1200m) in Okinawa Trough 
  %  (125-127E, pairs 193-205 ; Ganachaud 1999)
  q=find(lon>125 & lon<127);
  RV(q)=3e-3;
  % No transport at gamma>28.04 (3100m) in N.Phil. Basin
  %  (127-141E, pairs 163-193 ; Ganachaud 1999)
  q=find(lon>127 & lon<141);
  RV(q)=-3.5e-4;
  % Balance Ekman (Ek=8.26 Sv north) 
  RV=RV-5e-5;

elseif strcmp(sectname,'p01')
  q=find(glevels>=28.1);reflevel=q(1);
  eval(['load ',sectdir,'/p01_raw lon'])
  lon=lon(1:length(lon)-1)+diff(lon)/2;

  % No transport at gamma>28.1 in Kural Trench
  %  (145-147E, pairs 1-14; Ganachaud 1999)
  q=find(lon>145 & lon<147);
  RV(q)=6e-3;

  % Balance Ekman (Ek=3.96 Sv south)
  RV=RV-7e-4;

elseif strcmp(sectname,'i05p')
    
    eval(['load ',sectdir, ...
            '/i05p_raw lon lat bottom binPair_vel bin_press'])
    dist=cumsum(sw_dist(lat,lon,'km'));
    lon=lon(1:length(lon)-1)+diff(lon)/2;
    bottom=[bottom(1:length(bottom)-1),bottom(2:length(bottom))];
    bottom=nanmin(bottom');
    
    % bottom ref level before shifting (see below)
    reflevel=length(glevels);
    
    for j=1:length(lon);
      q=find(isfinite(binPair_vel(:,j)));
      binPair_vel(:,j)=binPair_vel(:,j)- ...
        binPair_vel(last(q),j);
    end;

    % East of 113.5E, e.g. against western Australia,
    %   shift ref level to 300m to capture southward
    %   surface Leeuwin Current and northward undercurrent
    %   [Smith et al. (1991), JPO 21, 323-345;
    %   Feng et al. (2003), JGR 108 (C11), 3355]
    % Between the eastern Natal Vally and 113.5E,
    %   shift ref level to 2000dbar 
    %  [Bryden and Beal (2001), DSR 48 (8), 1821-1845]
    % West of this, shift level of no motion
    % to the zero velocity level from LADCP
    %   [Beal & Bryden (1999), DSR I 44 (9-10), 1715-1724]
    %   700m at innermost station,
    %   depth 2500m at 80 km offshore,
    %   depth 1000m at 230 km offshore.
    %   (linear trend gives 2000m at 130 km offshore)
    % Note that different numbers are reported in
    % BB01: linear increase from 800dbar at shelf break to
    % 2900dbar at 60 km offshore, then linear decrease
    % to 2000dbar at 100 km offshore.  
    dd=[dist(1) 80 130];  % distances offshore
    zz=[700 2500 2000]; % corresponding depths for refvel
    % this gives net transport across Agulhas segment 
    % (pairs 1:9) of 72.6 Sv southward
    a=diff(zz)./diff(dd);
    b=[zz(1)-a(1)*dd(1) zz(3)-a(2)*dd(3)];
    
    % shift ref level to 300m in Leeuwin region
    %( lon>=113.5, pairs 99-105).  This gives
    % net southward transport of 3.1 Sv in these
    % pairs, agreeing well with Feng et al (2003)
    % mean value of 3.4 Sv.
    refp=300;
    q=min(find(bin_press>=refp));
    q2=find(bottom>=refp & lon>=113.5);
    RV(q2)=RV(q2)-binPair_vel(q,q2);
    q=find(isnan(RV(q2)));
    RV(q2(q))=0;
    
    % shift ref level to 2000dbar from the eastern 
    % Natal Valley to the western edge of the Leeuwin
    refp=2000;
    q=min(find(bin_press>=refp));
    q2=find(bottom>=refp & dist>=dd(3) & lon<113.5);
    RV(q2)=RV(q2)-binPair_vel(q,q2);
    q=find(isnan(RV(q2)));
    RV(q2(q))=0;
    
    % V-shaped Agulhas reference level
    q2=find(dist<dd(2));
    for ind=1:length(q2);
        refp=a(1)*dist(q2(ind))+b(1);
        q=min(find(bin_press>=refp));
        RV(ind)=RV(ind)-binPair_vel(q,q2(ind));
        if (isnan(RV(q2(ind))))
            RV(q2(ind))=0;
        end;
    end;
    q2=find(dist>=dd(2) & dist<dd(3));
    for ind=1:length(q2);
        refp=a(2)*dist(q2(ind))+b(2);
        q=min(find(bin_press>=refp));
        RV(ind)=RV(ind)-binPair_vel(q,q2(ind));
        if (isnan(RV(q2(ind))))
            RV(q2(ind))=0;
        end;
    end;
    
    
    % unadjusted, this gives 33Sv southward.
    % If balanced in interior (pairs 10:99)
    % to get net 16Sv southward (Ekman=.9 Sv N),
    % ones finds two problems:
    %   1. southward transport in deepest layers 42-43.
    %   2. northward transport of 1377 kmol/s silicate
    %      (associated with 23 Sv overturning circulation).
    %q=find(dist>=dd(3) & lon<113.5);
    %RV(q)=RV(q)+0.67e-3;
    % A better solution will have northward or zero
    % flow in deepest layers, and smaller silicate transport.
        
    % constraints from Ganachaud (1999), modified after
    %  pers. comm. with Lisa Beal.  These are applied
    %  to deep/bottom water, gamma>28.11, layers 36:45.
    
    % Natal Valley (pairs 1-13) is a cul-de-sac
    %   for BW: met by default (0.3 Sv)
    
    % Mozambique Basin (pairs 16-24) is a cul-de-sac.
    %   NOTE: Ganachaud has 1 Sv north.  
    %   NOTE2: adding uniform 4.43e-3 to these pairs
    %    achieves 0 net, layers 36:45, but also yields
    %    1.3 Sv south in densest two layers 42,43.
    %    Set these to zero, at expense of 2.9Sv
    %    net northward flow in layers 36:41
    q=find(lon>36.1 & lon<43.2); % pairs 16:24
    RV(q)=RV(q)+7.39e-3;
    
    % Madagascar-Crozet Basin (pairs 30-54): 
    %  2.5-3.8 Sv northward deep water (potmp<1.0-1.1degC;
    %   gamma>28.13, layers 37:45) feeds DWBC 
    %   in Mascarene Basin (Johnson, Musgrave, Warren,
    %   Ffield and Olson, 1998: JGR 103(C13), 30973-30984)
    % first, cancel southward transport of layers 42-43.
    q=find(lon>55 & lon<70);
    RV(q)=RV(q)+1.20e-3;
    % next, get 1 Sv north in overall M-C segment
    q=find(lon>47 & lon<55);
    RV(q)=RV(q)-1.58e-3;
    
    % Central Basin (pairs 57-67) BW (") cul-de-sac.
    q=find(lon>78 & lon<89);
    RV(q)=RV(q)-0.72e-3;
    
    % Bernadette Sloyan (presentation at Nice EGU 2004):
    %  10 moorings, 9 recovered between Broken and
    %  Naturaliste Plateaus (102-110 E), June 1995 to
    %  September 1996.  Analysis shows deep northward flow:
    %   0.6C < theta < 1.4C:  2.1 Sv.   
    %     IO5p, station 89 (105.7E):  3080-4590dbar, 28.09<gamman<28.2
    %   <0.6C: 1.6 Sv.
    % BS estimated total deep Nward flow: 3.7+-0.4 Sv at theta<1.4C
    q=find(lon>102 & lon<113.5);    % pairs 81-98
    RV(q)=RV(q)-3.30e-3;    % 3.7 Sv Nward layers 34-45 (theta<1.4C)
    
    % unadjusted, this gives 33Sv southward.
    % Balance over Southeast Indian Ridge
    % (87.6-99.2E) to get net 15Sv southward (Ekman=.9 Sv N)
    q=find(lon>87.6 & lon<99.2);
    RV(q)=RV(q)+6.30e-3;
    
    % transport below 2000dbar (this neglects bottom trias)
    load ../sections/i05p lon lat
    area=10*ones(length(bin_press),1)*sw_dist(lat,lon,'km')*1e3;
    T=area.*(binPair_vel+ones(length(bin_press),1)*RV);
    T=geometry*nansum(nansum(T(201:701,:)))/1e6;
    fprintf('Net overturning below 2000dbar: %3.1f Sv\n',T);

    if (0)
    % calculate net transport of silicate
    load ../sections/i05p lon lat
    area=10*ones(length(bin_press),1)*sw_dist(lat,lon,'km')*1e3;
    T=area.*(binPair_vel+ones(length(bin_press),1)*RV);
    load ../sections/i05p_raw directory
    eval(['load ',directory,'/i05p botSILCAT ctdpres'])
    % units of botSILCAT: micromol/kg.
    botSILCAT=botSILCAT(1:5:size(botSILCAT,1),:);
    botSILCAT=[botSILCAT;NaN*ones(701-606,length(lat))];
    bs=fillnans(botSILCAT,0);
    bs=bs(:,1:size(bs,2)-1)+diff(bs,[],2)/2;
    % 1e-6/1e3: kilomol/micromol
    transsil=1030*1e-6/1e3*geometry*nansum(nansum(bs.*T));
    fprintf('Net silicate: %5.0f kmol/s.\n',transsil);
    end;
    
    % these choices give a prior overturning of 16.0 Sv
    % below 2000 dbar; in density coordinates the
    % overturning is 16.7 Sv: 6.3 ACCbw and 9.6 Sv LCDW
    % northward balanced by 4.4 Sv UCDW (net) and 11.5 Sv 
    % mode water southward (+5.4 Sv mode southward as 
    % lower part of Pac.Ind.Throughflow).  It carries
    % a net transport of 545 kmol/sec silicate northward.
    %    This overturning is comparable to 
    % Robbins and Toole (1997) (12 Sv) and
    % Bryden and Beal (2001), as calculated in their
    % section 6: 10.1 Sv.
    % It is far smaller than Toole and Warren's
    % (1993) 25 Sv, which produces large silica
    % convergence (RT97).

elseif strcmp(sectname,'i04');
  q=find(glevels>=28.11); reflevel=q(1);
  eval(['load ',sectdir,'/i04_raw lon'])
  lon=lon(1:length(lon)-1)+diff(lon)/2;

  % No net in layers 28-45 (gamma>28.03;
  %     sill depth 2600m in Moz.Channel)
  q=find(lon>41 & lon<43.6);
  RV(q)=2e-3;

  % adjust against Africa and Madagascar 
  % to get southward net of 10Sv 
  % (see summary values in Chapman et al proposal)
  q=find(lon<=36.25 | lon>43.75);
  RV(q)=RV(q)-.115;

elseif strcmp(sectname,'mozambique')
  q=find(glevels>=28.11); reflevel=q(1);
  eval(['load ',sectdir,'/mozambique lon lat'])
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  lat=lat(1:length(lat)-1)+diff(lat)/2;

  % No net in layers 28-45 (gamma>28.03;
  %	sill depth 2600m in Moz.Channel)
  % NOTE: this still leaves 5Sv, but stronger
  % adjustment is worse for layers>33
  q=find(lat<-5.3 & lat>-11.2);
  RV(q)=7e-3;

  % Adjust against Africa to get net southward
  % flow of 10Sv (see i04)
  q=find(lon<42);
  RV(q)=.054;

elseif strcmp(sectname,'i02')
  q=find(glevels>=28.11); reflevel=q(1);
  eval(['load ',sectdir,'/i02_raw lon'])
  lon=lon(1:length(lon)-1)+diff(lon)/2;

  % 10Sv southward across western part of section
  %  (Indonesia to Australia)
  q=find(lon>105.6);
  RV(q)=1.55e-3;
  % In other stations, balance Ekman (11.66Sv S-ward)
  % and Mozam.Channel (10Sv S-ward), i.e.
  % get a net northward transport of 22Sv)
  q=find(lon<=105.6);
  RV(q)=-1.95e-3;

elseif strcmp(sectname,'ir06d');
    % JADE February 1992 section.  Primary reference:
    % Sprintall, J., S. Wijffels, T. Chareskin and
    % N. Bray, 2002: The JADE and WOCE I10/IR6
    % Throughflow sections in the southeast Indian
    % Ocean.  Part 2: velocity and transports.
    % DSR II (49), 1363-1389.
    %
    %
    % Primary differences between IR06d and other repeats:
    %    The Feb92 section best-sampled flow against 
    %   Indonesia.  Semiannually-reversing South Java
    %   Current (SJC) VERY strong eastward in Feb92.
    %   both SEC and EGC (Eastern Gyral C.) weaker than 
    %   ann.avg: typical February conditions.
    % Ekman: 0.65 Sv westward.
 
    eval(['load ',sectdir, ...
            '/ir06d_raw lat bottom binPair_vel bin_press'])
    lat=lat(1:length(lat)-1)+diff(lat)/2;
    bottom=[bottom(1:length(bottom)-1),bottom(2:length(bottom))];
    bottom=nanmin(bottom');
    
    % 29 March 2004: modified section so that it is masked
    % below 1200dbar, the sill depth of the Timor Passage.
    reflevel=length(glevels);
    
    % At this point, net transport is 1.8 Sv eastward.
    % Add westward vref in South Equatorial Current
    % to get PIT (12 Sv westward)
    q=find(lat>=-14 & lat<=-10); %pairs 15-22
    RV(q)=RV(q)+0.383;
    
    if (1)
    % net transport of silicate
    load ../sections/ir06d lon lat bin_press
    area=10*ones(length(bin_press),1)*sw_dist(lat,lon,'km')*1e3;
    T=area.*(binPair_vel+ones(length(bin_press),1)*RV);
    load ../sections/ir06d_raw directory
    eval(['load ',directory,'/ir06d botSILCAT ctdpres'])
    % units of botSILCAT: micromol/kg.
    botSILCAT=botSILCAT(1:5:size(botSILCAT,1),:);
    botSILCAT=fillnans(botSILCAT,0);
    bs=[botSILCAT;NaN*ones( ...
            length(bin_press)-size(botSILCAT,1), ...
            length(lat))];
    bs=bs(:,1:size(bs,2)-1)+diff(bs,[],2)/2;
    % 1e-6/1e3: kilomol/micromol
    transsil=1030*1e-6/1e3*geometry*nansum(nansum(bs.*T));
    fprintf('Net silicate: %5.0f kmol/s.\n',transsil);
    end;
  
  
elseif strcmp(sectname,'sr03c') % Tasmania to Antarctica
              % bottom reference level
  reflevel=length(glevels);
  load /phod007/lumpkin/dobox/sections/sr03c_raw ...
         binPair_vel surf_press bin_press
         
  for j=1:size(binPair_vel,2);
      if (isfinite(surf_press(reflevel,j)))
          q=find(bin_press==round(surf_press(reflevel,j)));
          q2=find(isfinite(binPair_vel(:,j)));
          RV(j)=RV(j)-binPair_vel(last(q2),j)+binPair_vel(q,j);
      end;
  end;
  % adjust to get 140+15=155Sv westward
  RV=RV-2e-3;
  
elseif strcmp(sectname,'drake90') % Drake
              % bottom reference level
  reflevel=length(glevels);
  load /phod007/lumpkin/dobox/sections/drake90_raw ...
         binPair_vel surf_press bin_press
         
  for j=1:size(binPair_vel,2);
      if (isfinite(surf_press(reflevel,j)))
          q=(bin_press-surf_press(reflevel,j)).^2;
          q=find(q==min(q));
          q2=find(isfinite(binPair_vel(:,j)));
          RV(j)=RV(j)-binPair_vel(last(q2),j)+binPair_vel(q,j);
      end;
  end;
  % adjust to get 140Sv westward
  RV=RV-2e-3
  
elseif strcmp(sectname,'i06b') % CIVA - S.Africa to S4
  %q=find(glevels>=28.292); reflevel=q(1);
    reflevel=length(glevels);
  load /phod007/lumpkin/dobox/sections/i06b_raw ...
         binPair_vel surf_press bin_press
         
  for j=1:size(binPair_vel,2);
      if (isfinite(surf_press(reflevel,j)))    
          q=(bin_press-surf_press(reflevel,j)).^2;
          q=find(q==min(q));
          q2=find(isfinite(binPair_vel(:,j)));
          RV(j)=RV(j)-binPair_vel(last(q2),j)+binPair_vel(q,j);
      end;
  end;
  RV=RV+2.2e-3; % shift prior net from 180Sv to 140Sv
elseif strcmp(sectname,'i06bs') % CIVA - S4 to Antarctica
    q=find(glevels>=28.292); reflevel=q(1);
elseif strcmp(sectname,'indant') % Sr03c - S4 to Antarctica
    q=find(glevels>=28.292); reflevel=q(1);
    RV(1:6)=RV(1:6)+0.07;
elseif strcmp(sectname,'wedsea')
    eval(['load ',sectdir,'/wedsea_raw lon']);
    lon=lon(1:length(lon)-1)+diff(lon)/2;
    
    q=find(glevels>=28.292); reflevel=q(1);
    % easternmost 8 pairs: 34.8 Sv southward 
    % (Wienders, pers.comm.)
    % (compares well to Fahrbach et al (1995): 29.5 Sv.
    q=find(lon>-16.817);
    RV(q)=RV(q)-2.9e-2;
    % westernmost 10 pairs: 26 Sv northward (Wienders)
    q=find(lon<-47.95);
    RV(q)=RV(q)+3.41e-2;
    % surface (gamma<28.18) layers, 41.517-47.95W:
    %   2.1 Sv north (Wienders).  Note: concentrate
    %   for western 1/3, where sfc layers are thickest,
    %   or transport of deep (gamma>28.27) water far 
    %   exceeds 5.3+-9 Sv.
    q=find(lon>-47.95 & lon<-45);
    RV(q)=RV(q)+3.05e-2;
    %%% westernmost 15 pairs: 33 Sv northward (").
    %%% Choices above give 44 Sv, but all zones within
    %%% Wienders' error bar estimates.
    
    % resulting net mass transport is 11 Sv north.
    % Adjust in center of section to balance Ekman
    % (0.9 Sv north).  NOTE: this adjustment yields
    % a net northward, not southward, transport of 1 Sv.
    % This is a compromise between the net constraint
    % and the constraint that Zone 7 has 0+-1 Sv.
    q=find(lon>-41.516 & lon<-30);
    RV(q)=RV(q)-3.88e-3;

elseif strcmp(sectname,'s4_atl')  
  % Ekman transport across section: 2.1 Sv northward
  eval(['load ',sectdir,'/s4_atl_raw lon']);
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  
  % reference level: 0 deg C. CDW/WSDW interface
  q=find(glevels>=28.292); reflevel=q(1);
  % 24 Jan 03: moved to 28.27 as per request from Alex Orsi
  q=find(glevels>=28.27); reflevel=q(1);
  
  % The reflevel choice 28.27 produces VERY STRONG
  % (11.8Sv) outflow in layer 45, pairs 57-59.
  % This export is inconsistent with the 4.28 Sv
  % exported across wedsea in layer 45.
  q=find(lon>-25 & lon<-22);
  RV(q)=RV(q)-4e-2;
  
  % add southward transport in eastern side of
  % recirculating dome, to get zero net transport
  % for layer 45 in pairs 65:94 (these pairs are
  % east of 13W, the western edge of the dome)
  q=find(lon>-11.55); % center of dome
  RV(q)=RV(q)-1.3e-3;
  
  % between 15W and the western edge (13W) of the
  % dome of recirculating dense water,
  % add northward barotropic to get section net 
  % .9 Sv export in layer 44, 4 Sv in layer 45
  q=find(lon>=-15 & lon<=-10.5);
  RV(q)=RV(q)+2e-2;
  
  % finally adjust to balance Ekman (2 Sv north)
  q=find(lon<-25);
  RV(q)=RV(q)-1.45e-3;
  
elseif strcmp(sectname,'s4_ind')  
  q=find(glevels>=28.27);reflevel=q(1);
  eval(['load ',sectdir,'/s4_ind_raw lon']);
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  
  % Kerguelen Plateau: 82.8E.  DWBC from 82.8 to 106E
  % (station pairs 45:62).  Layers 38-45 < 1degC potmp.
  % Donohue et al 1999: 38 Sv (+-12) in these layers.
  q=find(lon>=82.8 & lon<=106);
  RV(q)=RV(q)+8.73e-3;
  
  % flow through PET: Heywood et al 1999: 20 Sv
  % at theta<0 deg (layers 43:45)
  % This water enters the Weddell sector, or
  % exits between Kerguelen and Weddell Gyre
  % (lon>34 & lon<70; station pairs 8:35)
  % assume the latter in the prior thermal wind
  % by adding a barotropic component against the
  % bathymetric feature at 34E
  q=find(lon>34 & lon<40);
  RV(q)=RV(q)+1.43e-2;
  
  % balance Ekman (4.2 Sv northwards)
  q=find(lon<34 | lon>106);
  RV(q)=RV(q)-8.01e-3;
  
elseif strcmp(sectname,'s4_pac')  
  q=find(glevels>=28.27); reflevel=q(1);
  
  % Ross sea: 171E-159W (pairs 31:54)
  % Bellany Islands: 162.7E
  eval(['load ',sectdir,'/s4_pac_raw lon']);
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  
  % ~6 Sv in layers 43:45 from western Ross Sea
  q=find(lon>171 | lon<-178); %pairs 31-39
  RV(q)=RV(q)+1.08e-2;
  
  % balance Ekman (3.6 Sv northwards)
  % in southward current against AA Peninsula
  q=find(lon<0 & lon>-78);
  RV(q)=RV(q)-1.61e-2;
  
elseif strcmp(sectname,'s4comp')
  q=find(glevels>=28.292); reflevel=q(1);

  load /phod007/lumpkin/dobox/sections/s4comp_raw ...
	 binPair_vel lon bin_press bottom surf_press;
  lon=lon(1:length(lon)-1)+diff(lon)/2;
  bottom=bottom(1:length(bottom)-1)+diff(bottom)/2;
  for j=1:length(lon);
      if isfinite(surf_press(reflevel,j)) % reflev above bottom
          zind=(bin_press-surf_press(reflevel,j)).^2;
          zind=find(zind==min(zind));
          binPair_vel(:,j)=binPair_vel(:,j)- ...
              binPair_vel(zind,j);
      else  % reflevel too dense to be defined for this pair
          q=find(isfinite(binPair_vel(:,j)));
          binPair_vel(:,j)=binPair_vel(:,j)- ...
	        binPair_vel(last(q),j);
      end;
  end;
  % shift ref level to bottom where bottom>=1000m,
  %  and to surface where bottom<1000m or where,
  % on South Scotia Ridge (-60<=lon<-42), bottom<2000
  for j=1:length(lon);
      q=find(isfinite(binPair_vel(:,j)));
      if (bottom(j)>=1000 & (lon(j)<-60 | lon(j)>-42))
          % bottom ref level
          %RV(j)=RV(j)-binPair_vel(last(q),j);
      elseif (bottom(j)>=2000) % bottom for these SSR pairs
          %RV(j)=RV(j)-binPair_vel(last(q),j);
      else  % shallow: surface ref level
          RV(j)=RV(j)-binPair_vel(1,j);
      end;
  end;  

end;

eval(['save ',rvfilename,' RV Vmag']);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

DL=[]; E=[]; D=[]; bbase=[]; %reflevel=[];
[DL,E,D,bbase,reflevel] = ...
rhs_menu(nsections,geometry,sectfiles,properties,nsurfs,DL,E,D,bbase,reflevel);
%%%%%%%%%%% end of dobox code %%%%%%%%%%%%

if (exist('stnpairs'))  % only calculate flux for some pairs
  fprintf('Calculating flux for a segment of the section.\n');
  bbase=sum(D(:,stnpairs),2);
end;

F=ones(nlayers,nproperties);
for j=1:nproperties;
  F(:,j)=-bbase((j-1)*(nlayers+1)+1:j*(nlayers+1)-1);
end;

Fs=35*sum(F(:,1))+1000*sum(F(:,2));
Fs=Fs*1.027;

fprintf('Net mass flux: %3.2f Sv.\n',sum(F(:,1))/1e6);
fprintf('Net salt flux: %3.2fe6 kg/s.\n',Fs/1e6);
fprintf('Net heat flux: %3.2f PW.\n',sum(F(:,3)) ...
	/(1e15/3990/1027));


glev;
clf;

plot(F(:,1)/1e6,1:45,F(:,1)/1e6,1:45, ...
	'.k','markersize',10);
set(gca,'ydir','reverse');

!rm refvel_* geo.mat
!rm gvel_*


%f=[sum(F(11:19,1)) sum(F(20:37,1)) sum(F(36:45,1))]'/1e6
Psi=flipud(cumsum(flipud(F(:,1))))/1e6;
layerplot(Psi);
fprintf('Overturning: %3.1f Sv.\n',max(abs(Psi)));
