
% 48n_trans - store transports calculated from
% calcrelflux.m for the 48N repeats

% this routine assumes that calcrelflux.m
% is set up for the "WITH WBC ADJUSTMENTS" case.
% (the "no WBC" case is hard-coded)

clear all;
colr=0;     % set to 1 for color plot

% *_0 : no WBC included (adjusted level of no motion)
% without this extension, values include the WBC
%   modifications.

% N = net volume transport (Sv), salt anomaly (psu Sv)
%   and heat (degC Sv).
N_0=[[2.4972    0.0118  188.9165]; ...     % ar19a 1993
        [2.4959    0.0117  209.2373]; ...  % ar19c 1996
        [2.4411   -0.0021  142.3959]; ... % a02_97, 1997
        [2.4290    0.0097  192.3010]; ... % ar19d, 1998
        [2.4745    0.0086  167.0341]]; % ar19f, 2000
% Psi = overturning (Sv)
Psi_0=[17.7 22.4 19.2 19.8 15.6];
        
% lsw = layers 21-24
lsw_0=-[-4.0964 -5.6139 -5.5480 -4.3423 -4.9663];
% ldw = layers 31-36
ldw_0=-[-4.9822 -5.1301 -0.3253 -1.7599 0.1422];

% Now the values with the WBC adjustment

repeats={'ar19a' 'ar19c' 'a02_97' 'ar19d' 'ar19f'};
N=NaN*ones(length(repeats),3);
Psi=NaN*ones(length(repeats),1);
lsw=Psi; ldw=Psi;
for rpt=1:length(repeats);
    eval(['F=calcrelflux(''',char(repeats(rpt)), ...
            ''',1,-1,0);']);
    N(rpt,:)=sum(F/1e6);
    Psi(rpt)=max(abs(flipud(cumsum(flipud(F(:,1)/1e6)))));
    lsw(rpt)=-sum(F(21:24,1)/1e6);  % minus: southward pos.
    ldw(rpt)=-sum(F(31:36,1)/1e6);
end;

year=[1993 1996 1997 1998 2000]+.5;

clf;
wdth_mag=.03;
mksz=10;

subplot(411)    % OVERTURNING
%plot(year,N_0(:,3)*1e6*1028*3.9848e3/1e15,'ok', ...
%    year,N(:,3)*1e6*1028*3.9848e3/1e15,'*k','markersize',mksz);
%pos=get(gca,'pos');
%set(gca,'xticklabel',[],'pos',pos+[0 0 0 wdth_mag]);
%ylabel('PW','fontsize',12);
%text(1994,.6,'Heat','fontsize',12);
if ~colr
    plot(year,Psi_0,'ok','markersize',mksz);
    hold on; 
    plot(year,Psi,'.k','markersize',30);
    hold off;
else
    l=plot(year,Psi_0,'ok','markersize',10);
    set(l,'markerfacecolor','r','markeredgecolor','k');
    hold on;
    l=plot(year,Psi,'hb','markersize',13);
    set(l,'markerfacecolor','b','markeredgecolor',[0 0 .5]);
    line([1993 2001],[0 0],'color',[.5 .5 .5]);
    hold off;
end;
pos=get(gca,'pos');
set(gca,'xticklabel',[],'pos',pos+[0 0 0 wdth_mag]);
set(gca,'fontsize',12);
ylabel('Sv','fontsize',12);
text(1994,12,'Overturning','fontsize',12);

subplot(412)    % HEAT TRANSPORT
if (~colr)
    plot(year,N_0(:,3)*1e6*1028*3.9848e3/1e15,'ok','markersize',mksz);
    hold on;
    plot(year,N(:,3)*1e6*1028*3.9848e3/1e15,'.k','markersize',30);
    hold off;
else
    l=plot(year,N_0(:,3)*1e6*1028*3.9848e3/1e15,'ok', ...
        'markersize',10);
    set(l,'markerfacecolor','r','markeredgecolor','k');
    hold on;
    l=plot(year,N(:,3)*1e6*1028*3.9848e3/1e15,'hb', ...
        'markersize',13);
    set(l,'markerfacecolor','b','markeredgecolor',[0 0 .5]);
    line([1993 2001],[0 0],'color',[.5 .5 .5]);
    hold off;
end;
pos=get(gca,'pos');
set(gca,'xticklabel',[],'pos',pos+[0 0 0 wdth_mag]);
set(gca,'fontsize',12);
ylabel('PW','fontsize',12);
text(1994,.6,'Heat','fontsize',12);

subplot(413)  % LSW
if ~colr
    plot(year,lsw_0,'ok','markersize',mksz);
    hold on;
    plot(year,lsw,'.k','markersize',30);
    hold off;
else
    l=plot(year,lsw_0,'ok','markersize',10);
    set(l,'markerfacecolor','r','markeredgecolor','k');
    hold on;
    l=plot(year,lsw,'hb','markersize',13);
    set(l,'markerfacecolor','b','markeredgecolor',[0 0 .5]);
    line([1993 2001],[0 0],'color',[.5 .5 .5]);
    hold off;
end;
pos=get(gca,'pos');
set(gca,'xticklabel',[],'pos',pos+[0 0 0 wdth_mag]);
set(gca,'fontsize',12);
ylabel('Sv','fontsize',12);
text(1994,5,'LSW','fontsize',12);

subplot(414) % LDW
if ~colr
    plot(year,ldw_0,'ok','markersize',mksz);
    hold on;
    plot(year,ldw,'.k','markersize',30);
    line([1993 2001],[0 0],'color',[.5 .5 .5]);
    hold off;
else
    l=plot(year,ldw_0,'ok','markersize',10);
    set(l,'markerfacecolor','r','markeredgecolor','k');
    hold on;
    l=plot(year,ldw,'hb','markersize',13);
    set(l,'markerfacecolor','b','markeredgecolor',[0 0 .5]);
    line([1993 2001],[0 0],'color',[.5 .5 .5]);
    hold off;
end;
pos=get(gca,'pos');
set(gca,'pos',pos+[0 0 0 wdth_mag]);
set(gca,'fontsize',12);
ylabel('Sv','fontsize',12);
text(1994,3,'LDW','fontsize',12);

